# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual-tables.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import virtual_trends_pb2 as Protobuf_dot_virtual__trends__pb2
from . import virtual_sfv_pb2 as Protobuf_dot_virtual__sfv__pb2
from . import solar_field_common_pb2 as Protobuf_dot_solar__field__common__pb2
from . import common_models_pb2 as Protobuf_dot_common__models__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='virtual-tables.proto',
  package='Bsii.SolarFocus.Protobuf',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14virtual-tables.proto\x12\x18\x42sii.SolarFocus.Protobuf\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dProtobuf/virtual-trends.proto\x1a\x1aProtobuf/virtual-sfv.proto\x1a!Protobuf/solar-field-common.proto\x1a\x1cProtobuf/common-models.proto\"\xa3\x01\n\x12VirtualTablesQuery\x12K\n\x0ctrends_query\x18\x01 \x01(\x0b\x32\x35.Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput\x12@\n\tsfv_query\x18\x02 \x01(\x0b\x32-.Bsii.SolarFocus.Protobuf.SolarField.SfvQuery\"$\n\x14VirtualTableMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb1\x04\n\x13VirtualTablesModule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\nbase_image\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x05 \x01(\t\x12Y\n\x16sfv_calculation_method\x18\x06 \x01(\x0e\x32\x39.Bsii.SolarFocus.Protobuf.SolarField.SfvCalculationMethod\x12U\n\x19trends_calculation_method\x18\x07 \x01(\x0e\x32\x32.Bsii.SolarFocus.Protobuf.Trends.CalculationMethod\x12\x33\n\x10sample_frequency\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x0cinput_trends\x18\t \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleInputTag\x12G\n\x0einput_sfv_tags\x18\n \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleInputTag\x12\x45\n\routput_tables\x18\x0b \x03(\x0b\x32..Bsii.SolarFocus.Protobuf.VirtualTableMetadata\"\xa4\x01\n\x19VirtualTablesInputsResult\x12?\n\x03sfv\x18\x01 \x01(\x0b\x32\x32.Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto\x12\x46\n\x06trends\x18\x02 \x01(\x0b\x32\x36.Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResult*=\n\x0cResultStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fPARTIAL_SUCCESS\x10\x01\x12\x0b\n\x07\x46\x41ILURE\x10\x02\x32\x88\x01\n\x18VirtualTablesGrpcService\x12l\n\x07GetData\x12,.Bsii.SolarFocus.Protobuf.VirtualTablesQuery\x1a\x33.Bsii.SolarFocus.Protobuf.VirtualTablesInputsResultB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,Protobuf_dot_virtual__trends__pb2.DESCRIPTOR,Protobuf_dot_virtual__sfv__pb2.DESCRIPTOR,Protobuf_dot_solar__field__common__pb2.DESCRIPTOR,Protobuf_dot_common__models__pb2.DESCRIPTOR,])

_RESULTSTATUS = _descriptor.EnumDescriptor(
  name='ResultStatus',
  full_name='Bsii.SolarFocus.Protobuf.ResultStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTIAL_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1141,
  serialized_end=1202,
)
_sym_db.RegisterEnumDescriptor(_RESULTSTATUS)

ResultStatus = enum_type_wrapper.EnumTypeWrapper(_RESULTSTATUS)
SUCCESS = 0
PARTIAL_SUCCESS = 1
FAILURE = 2



_VIRTUALTABLESQUERY = _descriptor.Descriptor(
  name='VirtualTablesQuery',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTablesQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trends_query', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesQuery.trends_query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sfv_query', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesQuery.sfv_query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=370,
)


_VIRTUALTABLEMETADATA = _descriptor.Descriptor(
  name='VirtualTableMetadata',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTableMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.VirtualTableMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=408,
)


_VIRTUALTABLESMODULE = _descriptor.Descriptor(
  name='VirtualTablesModule',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_image', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.base_image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.environment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sfv_calculation_method', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.sfv_calculation_method', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trends_calculation_method', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.trends_calculation_method', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.sample_frequency', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_trends', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.input_trends', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_sfv_tags', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.input_sfv_tags', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_tables', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesModule.output_tables', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=972,
)


_VIRTUALTABLESINPUTSRESULT = _descriptor.Descriptor(
  name='VirtualTablesInputsResult',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTablesInputsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sfv', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesInputsResult.sfv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trends', full_name='Bsii.SolarFocus.Protobuf.VirtualTablesInputsResult.trends', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1139,
)

_VIRTUALTABLESQUERY.fields_by_name['trends_query'].message_type = Protobuf_dot_virtual__trends__pb2._TIMESERIESQUERYINPUT
_VIRTUALTABLESQUERY.fields_by_name['sfv_query'].message_type = Protobuf_dot_virtual__sfv__pb2._SFVQUERY
_VIRTUALTABLESMODULE.fields_by_name['sfv_calculation_method'].enum_type = Protobuf_dot_solar__field__common__pb2._SFVCALCULATIONMETHOD
_VIRTUALTABLESMODULE.fields_by_name['trends_calculation_method'].enum_type = Protobuf_dot_virtual__trends__pb2._CALCULATIONMETHOD
_VIRTUALTABLESMODULE.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VIRTUALTABLESMODULE.fields_by_name['input_trends'].message_type = Protobuf_dot_common__models__pb2._VIRTUALMODULEINPUTTAG
_VIRTUALTABLESMODULE.fields_by_name['input_sfv_tags'].message_type = Protobuf_dot_common__models__pb2._VIRTUALMODULEINPUTTAG
_VIRTUALTABLESMODULE.fields_by_name['output_tables'].message_type = _VIRTUALTABLEMETADATA
_VIRTUALTABLESINPUTSRESULT.fields_by_name['sfv'].message_type = Protobuf_dot_solar__field__common__pb2._SOLARFIELDDTO
_VIRTUALTABLESINPUTSRESULT.fields_by_name['trends'].message_type = Protobuf_dot_virtual__trends__pb2._TIMESERIESQUERYRESULT
DESCRIPTOR.message_types_by_name['VirtualTablesQuery'] = _VIRTUALTABLESQUERY
DESCRIPTOR.message_types_by_name['VirtualTableMetadata'] = _VIRTUALTABLEMETADATA
DESCRIPTOR.message_types_by_name['VirtualTablesModule'] = _VIRTUALTABLESMODULE
DESCRIPTOR.message_types_by_name['VirtualTablesInputsResult'] = _VIRTUALTABLESINPUTSRESULT
DESCRIPTOR.enum_types_by_name['ResultStatus'] = _RESULTSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VirtualTablesQuery = _reflection.GeneratedProtocolMessageType('VirtualTablesQuery', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTABLESQUERY,
  '__module__' : 'virtual_tables_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTablesQuery)
  })
_sym_db.RegisterMessage(VirtualTablesQuery)

VirtualTableMetadata = _reflection.GeneratedProtocolMessageType('VirtualTableMetadata', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTABLEMETADATA,
  '__module__' : 'virtual_tables_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTableMetadata)
  })
_sym_db.RegisterMessage(VirtualTableMetadata)

VirtualTablesModule = _reflection.GeneratedProtocolMessageType('VirtualTablesModule', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTABLESMODULE,
  '__module__' : 'virtual_tables_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTablesModule)
  })
_sym_db.RegisterMessage(VirtualTablesModule)

VirtualTablesInputsResult = _reflection.GeneratedProtocolMessageType('VirtualTablesInputsResult', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTABLESINPUTSRESULT,
  '__module__' : 'virtual_tables_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTablesInputsResult)
  })
_sym_db.RegisterMessage(VirtualTablesInputsResult)


DESCRIPTOR._options = None

_VIRTUALTABLESGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualTablesGrpcService',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTablesGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1205,
  serialized_end=1341,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetData',
    full_name='Bsii.SolarFocus.Protobuf.VirtualTablesGrpcService.GetData',
    index=0,
    containing_service=None,
    input_type=_VIRTUALTABLESQUERY,
    output_type=_VIRTUALTABLESINPUTSRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALTABLESGRPCSERVICE)

DESCRIPTOR.services_by_name['VirtualTablesGrpcService'] = _VIRTUALTABLESGRPCSERVICE

# @@protoc_insertion_point(module_scope)
