# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common-models.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common-models.proto',
  package='Bsii.SolarFocus.Protobuf',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x63ommon-models.proto\x12\x18\x42sii.SolarFocus.Protobuf\"\xa6\x01\n\x15VirtualModuleInputTag\x12<\n\x06raw_id\x18\x01 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12\x10\n\x08tag_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_name\x18\x03 \x01(\t\x12\x11\n\tsource_id\x18\x04 \x01(\x05\x12\x15\n\rvariable_name\x18\x05 \x01(\t\"\xbb\x02\n\x12TagsIdentifierBase\x12;\n\x08tag_type\x18\x01 \x01(\x0e\x32).Bsii.SolarFocus.Protobuf.IdentifierTypes\x12\x41\n\x0etag_identifier\x18\x02 \x01(\x0b\x32\'.Bsii.SolarFocus.Protobuf.TagIdentifierH\x00\x12P\n\x16virtual_tag_identifier\x18\x03 \x01(\x0b\x32..Bsii.SolarFocus.Protobuf.VirtualTagIdentifierH\x00\x12H\n\x12sfo_tag_identifier\x18\x04 \x01(\x0b\x32*.Bsii.SolarFocus.Protobuf.SfoTagIdentifierH\x00\x42\t\n\x07subtype\"\x1b\n\rTagIdentifier\x12\n\n\x02id\x18\x01 \x01(\x05\"2\n\x10SfoTagIdentifier\x12\x0e\n\x06tag_id\x18\x01 \x01(\x05\x12\x0e\n\x06sfo_id\x18\x02 \x01(\x05\"@\n\x14VirtualTagIdentifier\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\"^\n\x0eProblematicTag\x12<\n\x06tag_id\x18\x01 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12\x0e\n\x06reason\x18\x02 \x01(\t*J\n\x0fIdentifierTypes\x12\x08\n\x04ZERO\x10\x00\x12\x0b\n\x07NUMERIC\x10\x01\x12\x13\n\x0fNUMERIC_PER_SFO\x10\x02\x12\x0b\n\x07VIRTUAL\x10\x03\x42\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
)

_IDENTIFIERTYPES = _descriptor.EnumDescriptor(
  name='IdentifierTypes',
  full_name='Bsii.SolarFocus.Protobuf.IdentifierTypes',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERIC_PER_SFO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=779,
  serialized_end=853,
)
_sym_db.RegisterEnumDescriptor(_IDENTIFIERTYPES)

IdentifierTypes = enum_type_wrapper.EnumTypeWrapper(_IDENTIFIERTYPES)
ZERO = 0
NUMERIC = 1
NUMERIC_PER_SFO = 2
VIRTUAL = 3



_VIRTUALMODULEINPUTTAG = _descriptor.Descriptor(
  name='VirtualModuleInputTag',
  full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_id', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.raw_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.tag_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.source_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.source_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.variable_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=216,
)


_TAGSIDENTIFIERBASE = _descriptor.Descriptor(
  name='TagsIdentifierBase',
  full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_type', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.tag_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_identifier', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.tag_identifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_tag_identifier', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.virtual_tag_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sfo_tag_identifier', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.sfo_tag_identifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='subtype', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.subtype',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=219,
  serialized_end=534,
)


_TAGIDENTIFIER = _descriptor.Descriptor(
  name='TagIdentifier',
  full_name='Bsii.SolarFocus.Protobuf.TagIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Bsii.SolarFocus.Protobuf.TagIdentifier.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=563,
)


_SFOTAGIDENTIFIER = _descriptor.Descriptor(
  name='SfoTagIdentifier',
  full_name='Bsii.SolarFocus.Protobuf.SfoTagIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_id', full_name='Bsii.SolarFocus.Protobuf.SfoTagIdentifier.tag_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sfo_id', full_name='Bsii.SolarFocus.Protobuf.SfoTagIdentifier.sfo_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=615,
)


_VIRTUALTAGIDENTIFIER = _descriptor.Descriptor(
  name='VirtualTagIdentifier',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_name', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier.module_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_name', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier.output_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=681,
)


_PROBLEMATICTAG = _descriptor.Descriptor(
  name='ProblematicTag',
  full_name='Bsii.SolarFocus.Protobuf.ProblematicTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_id', full_name='Bsii.SolarFocus.Protobuf.ProblematicTag.tag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='Bsii.SolarFocus.Protobuf.ProblematicTag.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=777,
)

_VIRTUALMODULEINPUTTAG.fields_by_name['raw_id'].message_type = _TAGSIDENTIFIERBASE
_TAGSIDENTIFIERBASE.fields_by_name['tag_type'].enum_type = _IDENTIFIERTYPES
_TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'].message_type = _TAGIDENTIFIER
_TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'].message_type = _VIRTUALTAGIDENTIFIER
_TAGSIDENTIFIERBASE.fields_by_name['sfo_tag_identifier'].message_type = _SFOTAGIDENTIFIER
_TAGSIDENTIFIERBASE.oneofs_by_name['subtype'].fields.append(
  _TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'])
_TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'].containing_oneof = _TAGSIDENTIFIERBASE.oneofs_by_name['subtype']
_TAGSIDENTIFIERBASE.oneofs_by_name['subtype'].fields.append(
  _TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'])
_TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'].containing_oneof = _TAGSIDENTIFIERBASE.oneofs_by_name['subtype']
_TAGSIDENTIFIERBASE.oneofs_by_name['subtype'].fields.append(
  _TAGSIDENTIFIERBASE.fields_by_name['sfo_tag_identifier'])
_TAGSIDENTIFIERBASE.fields_by_name['sfo_tag_identifier'].containing_oneof = _TAGSIDENTIFIERBASE.oneofs_by_name['subtype']
_PROBLEMATICTAG.fields_by_name['tag_id'].message_type = _TAGSIDENTIFIERBASE
DESCRIPTOR.message_types_by_name['VirtualModuleInputTag'] = _VIRTUALMODULEINPUTTAG
DESCRIPTOR.message_types_by_name['TagsIdentifierBase'] = _TAGSIDENTIFIERBASE
DESCRIPTOR.message_types_by_name['TagIdentifier'] = _TAGIDENTIFIER
DESCRIPTOR.message_types_by_name['SfoTagIdentifier'] = _SFOTAGIDENTIFIER
DESCRIPTOR.message_types_by_name['VirtualTagIdentifier'] = _VIRTUALTAGIDENTIFIER
DESCRIPTOR.message_types_by_name['ProblematicTag'] = _PROBLEMATICTAG
DESCRIPTOR.enum_types_by_name['IdentifierTypes'] = _IDENTIFIERTYPES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VirtualModuleInputTag = _reflection.GeneratedProtocolMessageType('VirtualModuleInputTag', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALMODULEINPUTTAG,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualModuleInputTag)
  })
_sym_db.RegisterMessage(VirtualModuleInputTag)

TagsIdentifierBase = _reflection.GeneratedProtocolMessageType('TagsIdentifierBase', (_message.Message,), {
  'DESCRIPTOR' : _TAGSIDENTIFIERBASE,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsIdentifierBase)
  })
_sym_db.RegisterMessage(TagsIdentifierBase)

TagIdentifier = _reflection.GeneratedProtocolMessageType('TagIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _TAGIDENTIFIER,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagIdentifier)
  })
_sym_db.RegisterMessage(TagIdentifier)

SfoTagIdentifier = _reflection.GeneratedProtocolMessageType('SfoTagIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _SFOTAGIDENTIFIER,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SfoTagIdentifier)
  })
_sym_db.RegisterMessage(SfoTagIdentifier)

VirtualTagIdentifier = _reflection.GeneratedProtocolMessageType('VirtualTagIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTAGIDENTIFIER,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTagIdentifier)
  })
_sym_db.RegisterMessage(VirtualTagIdentifier)

ProblematicTag = _reflection.GeneratedProtocolMessageType('ProblematicTag', (_message.Message,), {
  'DESCRIPTOR' : _PROBLEMATICTAG,
  '__module__' : 'common_models_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.ProblematicTag)
  })
_sym_db.RegisterMessage(ProblematicTag)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
