# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: solar-field.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import common_models_pb2 as Protobuf_dot_common__models__pb2
from . import solar_field_common_pb2 as Protobuf_dot_solar__field__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='solar-field.proto',
  package='Bsii.SolarFocus.Protobuf.SolarField',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11solar-field.proto\x12#Bsii.SolarFocus.Protobuf.SolarField\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cProtobuf/common-models.proto\x1a!Protobuf/solar-field-common.proto\"\xfc\x02\n\x14StreamSolarFieldArgs\x12\x32\n\x0estart_time_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nd_time_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x10sample_frequency\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06margin\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12U\n\x12\x63\x61lculation_method\x18\x05 \x01(\x0e\x32\x39.Bsii.SolarFocus.Protobuf.SolarField.SfvCalculationMethod\x12G\n\x11tags_descriptions\x18\x06 \x03(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase2\x92\x01\n\nSolarField\x12\x83\x01\n\x10StreamSolarField\x12\x39.Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs\x1a\x32.Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto0\x01\x42\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,Protobuf_dot_common__models__pb2.DESCRIPTOR,Protobuf_dot_solar__field__common__pb2.DESCRIPTOR,])




_STREAMSOLARFIELDARGS = _descriptor.Descriptor(
  name='StreamSolarFieldArgs',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time_utc', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.start_time_utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_utc', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.end_time_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.sample_frequency', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.margin', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.calculation_method', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags_descriptions', full_name='Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs.tags_descriptions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=569,
)

_STREAMSOLARFIELDARGS.fields_by_name['start_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMSOLARFIELDARGS.fields_by_name['end_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMSOLARFIELDARGS.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMSOLARFIELDARGS.fields_by_name['margin'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMSOLARFIELDARGS.fields_by_name['calculation_method'].enum_type = Protobuf_dot_solar__field__common__pb2._SFVCALCULATIONMETHOD
_STREAMSOLARFIELDARGS.fields_by_name['tags_descriptions'].message_type = Protobuf_dot_common__models__pb2._TAGSIDENTIFIERBASE
DESCRIPTOR.message_types_by_name['StreamSolarFieldArgs'] = _STREAMSOLARFIELDARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamSolarFieldArgs = _reflection.GeneratedProtocolMessageType('StreamSolarFieldArgs', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSOLARFIELDARGS,
  '__module__' : 'solar_field_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.StreamSolarFieldArgs)
  })
_sym_db.RegisterMessage(StreamSolarFieldArgs)


DESCRIPTOR._options = None

_SOLARFIELD = _descriptor.ServiceDescriptor(
  name='SolarField',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.SolarField',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=572,
  serialized_end=718,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamSolarField',
    full_name='Bsii.SolarFocus.Protobuf.SolarField.SolarField.StreamSolarField',
    index=0,
    containing_service=None,
    input_type=_STREAMSOLARFIELDARGS,
    output_type=Protobuf_dot_solar__field__common__pb2._SOLARFIELDDTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SOLARFIELD)

DESCRIPTOR.services_by_name['SolarField'] = _SOLARFIELD

# @@protoc_insertion_point(module_scope)
