# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tags-metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import common_models_pb2 as Protobuf_dot_common__models__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tags-metadata.proto',
  package='Bsii.SolarFocus.Protobuf.TagsMetadata',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13tags-metadata.proto\x12%Bsii.SolarFocus.Protobuf.TagsMetadata\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cProtobuf/common-models.proto\"-\n\x0e\x45numMappingDto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"\xb2\x04\n\x06TagDto\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x31\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\tmin_value\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12.\n\tmax_value\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x04name\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tsource_id\x18\x07 \x01(\x05\x12*\n\x04unit\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13raw_enum_definition\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x06status\x18\n \x01(\x0e\x32\x33.Bsii.SolarFocus.Protobuf.TagsMetadata.EntityStatus\x12T\n\x0c\x65num_mapping\x18\x0b \x03(\x0b\x32>.Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.EnumMappingEntry\x1a\x32\n\x10\x45numMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\rDataSourceDto\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x0fidentifier_type\x18\x03 \x01(\x0e\x32).Bsii.SolarFocus.Protobuf.IdentifierTypes\x12\x11\n\tsite_name\x18\x04 \x01(\t\"|\n\x0cUnitMetadata\x12\x0c\n\x04Unit\x18\x01 \x01(\t\x12.\n\tmin_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12.\n\tmax_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xe1\x01\n\x0fTagsMetadataDto\x12I\n\x0b\x44\x61taSources\x18\x01 \x03(\x0b\x32\x34.Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto\x12;\n\x04Tags\x18\x02 \x03(\x0b\x32-.Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto\x12\x46\n\tUnitTypes\x18\x03 \x03(\x0b\x32\x33.Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata*B\n\x0c\x45ntityStatus\x12\x08\n\x04ZERO\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x0f\n\x0b\x44ISAPPEARED\x10\x03\x32\xbd\x03\n\x17TagsMetadataGrpcService\x12j\n\x18GetUnfilteredAllMetaData\x12\x16.google.protobuf.Empty\x1a\x36.Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto\x12q\n\x19GetUnfilteredSiteMetaData\x12\x1c.google.protobuf.StringValue\x1a\x36.Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto\x12g\n\x0fGetSiteMetaData\x12\x1c.google.protobuf.StringValue\x1a\x36.Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto\x12Z\n\x11UpdateTagMetaData\x12-.Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto\x1a\x16.google.protobuf.EmptyB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,Protobuf_dot_common__models__pb2.DESCRIPTOR,])

_ENTITYSTATUS = _descriptor.EnumDescriptor(
  name='EntityStatus',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.EntityStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISAPPEARED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1315,
  serialized_end=1381,
)
_sym_db.RegisterEnumDescriptor(_ENTITYSTATUS)

EntityStatus = enum_type_wrapper.EnumTypeWrapper(_ENTITYSTATUS)
ZERO = 0
ACTIVE = 1
DELETED = 2
DISAPPEARED = 3



_ENUMMAPPINGDTO = _descriptor.Descriptor(
  name='EnumMappingDto',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.EnumMappingDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.EnumMappingDto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.EnumMappingDto.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=263,
)


_TAGDTO_ENUMMAPPINGENTRY = _descriptor.Descriptor(
  name='EnumMappingEntry',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.EnumMappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.EnumMappingEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.EnumMappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=828,
)

_TAGDTO = _descriptor.Descriptor(
  name='TagDto',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.min_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.max_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.name', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.source_id', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.unit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_enum_definition', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.raw_enum_definition', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.status', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum_mapping', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.enum_mapping', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TAGDTO_ENUMMAPPINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=828,
)


_DATASOURCEDTO = _descriptor.Descriptor(
  name='DataSourceDto',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier_type', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto.identifier_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_name', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto.site_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=959,
)


_UNITMETADATA = _descriptor.Descriptor(
  name='UnitMetadata',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Unit', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata.Unit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata.min_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata.max_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1085,
)


_TAGSMETADATADTO = _descriptor.Descriptor(
  name='TagsMetadataDto',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='DataSources', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto.DataSources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Tags', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto.Tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UnitTypes', full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto.UnitTypes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1088,
  serialized_end=1313,
)

_TAGDTO_ENUMMAPPINGENTRY.containing_type = _TAGDTO
_TAGDTO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGDTO.fields_by_name['min_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TAGDTO.fields_by_name['max_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TAGDTO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGDTO.fields_by_name['unit'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGDTO.fields_by_name['raw_enum_definition'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGDTO.fields_by_name['status'].enum_type = _ENTITYSTATUS
_TAGDTO.fields_by_name['enum_mapping'].message_type = _TAGDTO_ENUMMAPPINGENTRY
_DATASOURCEDTO.fields_by_name['identifier_type'].enum_type = Protobuf_dot_common__models__pb2._IDENTIFIERTYPES
_UNITMETADATA.fields_by_name['min_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_UNITMETADATA.fields_by_name['max_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TAGSMETADATADTO.fields_by_name['DataSources'].message_type = _DATASOURCEDTO
_TAGSMETADATADTO.fields_by_name['Tags'].message_type = _TAGDTO
_TAGSMETADATADTO.fields_by_name['UnitTypes'].message_type = _UNITMETADATA
DESCRIPTOR.message_types_by_name['EnumMappingDto'] = _ENUMMAPPINGDTO
DESCRIPTOR.message_types_by_name['TagDto'] = _TAGDTO
DESCRIPTOR.message_types_by_name['DataSourceDto'] = _DATASOURCEDTO
DESCRIPTOR.message_types_by_name['UnitMetadata'] = _UNITMETADATA
DESCRIPTOR.message_types_by_name['TagsMetadataDto'] = _TAGSMETADATADTO
DESCRIPTOR.enum_types_by_name['EntityStatus'] = _ENTITYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnumMappingDto = _reflection.GeneratedProtocolMessageType('EnumMappingDto', (_message.Message,), {
  'DESCRIPTOR' : _ENUMMAPPINGDTO,
  '__module__' : 'tags_metadata_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.EnumMappingDto)
  })
_sym_db.RegisterMessage(EnumMappingDto)

TagDto = _reflection.GeneratedProtocolMessageType('TagDto', (_message.Message,), {

  'EnumMappingEntry' : _reflection.GeneratedProtocolMessageType('EnumMappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _TAGDTO_ENUMMAPPINGENTRY,
    '__module__' : 'tags_metadata_pb2'
    # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto.EnumMappingEntry)
    })
  ,
  'DESCRIPTOR' : _TAGDTO,
  '__module__' : 'tags_metadata_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.TagDto)
  })
_sym_db.RegisterMessage(TagDto)
_sym_db.RegisterMessage(TagDto.EnumMappingEntry)

DataSourceDto = _reflection.GeneratedProtocolMessageType('DataSourceDto', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEDTO,
  '__module__' : 'tags_metadata_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.DataSourceDto)
  })
_sym_db.RegisterMessage(DataSourceDto)

UnitMetadata = _reflection.GeneratedProtocolMessageType('UnitMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UNITMETADATA,
  '__module__' : 'tags_metadata_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.UnitMetadata)
  })
_sym_db.RegisterMessage(UnitMetadata)

TagsMetadataDto = _reflection.GeneratedProtocolMessageType('TagsMetadataDto', (_message.Message,), {
  'DESCRIPTOR' : _TAGSMETADATADTO,
  '__module__' : 'tags_metadata_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataDto)
  })
_sym_db.RegisterMessage(TagsMetadataDto)


DESCRIPTOR._options = None
_TAGDTO_ENUMMAPPINGENTRY._options = None

_TAGSMETADATAGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='TagsMetadataGrpcService',
  full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1384,
  serialized_end=1829,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUnfilteredAllMetaData',
    full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService.GetUnfilteredAllMetaData',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_TAGSMETADATADTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUnfilteredSiteMetaData',
    full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService.GetUnfilteredSiteMetaData',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=_TAGSMETADATADTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSiteMetaData',
    full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService.GetSiteMetaData',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=_TAGSMETADATADTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTagMetaData',
    full_name='Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService.UpdateTagMetaData',
    index=3,
    containing_service=None,
    input_type=_TAGDTO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TAGSMETADATAGRPCSERVICE)

DESCRIPTOR.services_by_name['TagsMetadataGrpcService'] = _TAGSMETADATAGRPCSERVICE

# @@protoc_insertion_point(module_scope)
