# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: layout.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='layout.proto',
  package='Bsii.SolarFocus.Protobuf.Layout',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0clayout.proto\x12\x1f\x42sii.SolarFocus.Protobuf.Layout\x1a\x1egoogle/protobuf/wrappers.proto\"\xef\x01\n\x0cTypedSfoList\x12:\n\x08sfo_type\x18\x01 \x01(\x0e\x32(.Bsii.SolarFocus.Protobuf.Layout.SfoType\x12\x0f\n\x03ids\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\r\n\x05names\x18\x03 \x03(\t\x12\x16\n\nlocation_e\x18\x04 \x03(\x02\x42\x02\x10\x01\x12\x16\n\nlocation_n\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x16\n\nlocation_z\x18\x06 \x03(\x02\x42\x02\x10\x01\x12;\n\x05types\x18\x07 \x03(\x0e\x32(.Bsii.SolarFocus.Protobuf.Layout.SfoTypeB\x02\x10\x01\"K\n\tLayoutDto\x12>\n\x07layouts\x18\x01 \x03(\x0b\x32-.Bsii.SolarFocus.Protobuf.Layout.TypedSfoList*+\n\x07SfoType\x12\x08\n\x04ZERO\x10\x00\x12\r\n\tHELIOSTAT\x10\x01\x12\x07\n\x03\x41PU\x10\x02\x32j\n\x11LayoutGrpcService\x12U\n\tGetLayout\x12\x1c.google.protobuf.StringValue\x1a*.Bsii.SolarFocus.Protobuf.Layout.LayoutDtoB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_SFOTYPE = _descriptor.EnumDescriptor(
  name='SfoType',
  full_name='Bsii.SolarFocus.Protobuf.Layout.SfoType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HELIOSTAT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APU', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=400,
  serialized_end=443,
)
_sym_db.RegisterEnumDescriptor(_SFOTYPE)

SfoType = enum_type_wrapper.EnumTypeWrapper(_SFOTYPE)
ZERO = 0
HELIOSTAT = 1
APU = 2



_TYPEDSFOLIST = _descriptor.Descriptor(
  name='TypedSfoList',
  full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sfo_type', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.sfo_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_e', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.location_e', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_n', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.location_n', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_z', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.location_z', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='Bsii.SolarFocus.Protobuf.Layout.TypedSfoList.types', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=321,
)


_LAYOUTDTO = _descriptor.Descriptor(
  name='LayoutDto',
  full_name='Bsii.SolarFocus.Protobuf.Layout.LayoutDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='layouts', full_name='Bsii.SolarFocus.Protobuf.Layout.LayoutDto.layouts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=398,
)

_TYPEDSFOLIST.fields_by_name['sfo_type'].enum_type = _SFOTYPE
_TYPEDSFOLIST.fields_by_name['types'].enum_type = _SFOTYPE
_LAYOUTDTO.fields_by_name['layouts'].message_type = _TYPEDSFOLIST
DESCRIPTOR.message_types_by_name['TypedSfoList'] = _TYPEDSFOLIST
DESCRIPTOR.message_types_by_name['LayoutDto'] = _LAYOUTDTO
DESCRIPTOR.enum_types_by_name['SfoType'] = _SFOTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TypedSfoList = _reflection.GeneratedProtocolMessageType('TypedSfoList', (_message.Message,), {
  'DESCRIPTOR' : _TYPEDSFOLIST,
  '__module__' : 'layout_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Layout.TypedSfoList)
  })
_sym_db.RegisterMessage(TypedSfoList)

LayoutDto = _reflection.GeneratedProtocolMessageType('LayoutDto', (_message.Message,), {
  'DESCRIPTOR' : _LAYOUTDTO,
  '__module__' : 'layout_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Layout.LayoutDto)
  })
_sym_db.RegisterMessage(LayoutDto)


DESCRIPTOR._options = None
_TYPEDSFOLIST.fields_by_name['ids']._options = None
_TYPEDSFOLIST.fields_by_name['location_e']._options = None
_TYPEDSFOLIST.fields_by_name['location_n']._options = None
_TYPEDSFOLIST.fields_by_name['location_z']._options = None
_TYPEDSFOLIST.fields_by_name['types']._options = None

_LAYOUTGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='LayoutGrpcService',
  full_name='Bsii.SolarFocus.Protobuf.Layout.LayoutGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=445,
  serialized_end=551,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLayout',
    full_name='Bsii.SolarFocus.Protobuf.Layout.LayoutGrpcService.GetLayout',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=_LAYOUTDTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LAYOUTGRPCSERVICE)

DESCRIPTOR.services_by_name['LayoutGrpcService'] = _LAYOUTGRPCSERVICE

# @@protoc_insertion_point(module_scope)
