# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: solar-field-common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_models_pb2 as Protobuf_dot_common__models__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='solar-field-common.proto',
  package='Bsii.SolarFocus.Protobuf.SolarField',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18solar-field-common.proto\x12#Bsii.SolarFocus.Protobuf.SolarField\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cProtobuf/common-models.proto\"\xac\x01\n\x07TagData\x12<\n\x06tag_id\x18\x01 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12/\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\rnullable_data\x18\x03 \x03(\x0b\x32\x1b.google.protobuf.FloatValue\"\x8f\x01\n\rSolarFieldDto\x12:\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32,.Bsii.SolarFocus.Protobuf.SolarField.TagData\x12\x42\n\x10problematic_tags\x18\x02 \x03(\x0b\x32(.Bsii.SolarFocus.Protobuf.ProblematicTag*\x8e\x01\n\x14SfvCalculationMethod\x12\x10\n\x0c\x41NOTHER_ZERO\x10\x00\x12\x12\n\x0e\x43LOSEST_SAMPLE\x10\x01\x12\x1c\n\x18\x41VERAGE_OVER_SAMPLE_FREQ\x10\x02\x12\x18\n\x14MAX_OVER_SAMPLE_FREQ\x10\x03\x12\x18\n\x14MIN_OVER_SAMPLE_FREQ\x10\x04\x42\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,Protobuf_dot_common__models__pb2.DESCRIPTOR,])

_SFVCALCULATIONMETHOD = _descriptor.EnumDescriptor(
  name='SfvCalculationMethod',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvCalculationMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANOTHER_ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOSEST_SAMPLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVERAGE_OVER_SAMPLE_FREQ', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_OVER_SAMPLE_FREQ', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN_OVER_SAMPLE_FREQ', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_SFVCALCULATIONMETHOD)

SfvCalculationMethod = enum_type_wrapper.EnumTypeWrapper(_SFVCALCULATIONMETHOD)
ANOTHER_ZERO = 0
CLOSEST_SAMPLE = 1
AVERAGE_OVER_SAMPLE_FREQ = 2
MAX_OVER_SAMPLE_FREQ = 3
MIN_OVER_SAMPLE_FREQ = 4



_TAGDATA = _descriptor.Descriptor(
  name='TagData',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.TagData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_id', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagData.tag_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagData.update_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nullable_data', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagData.nullable_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=333,
)


_SOLARFIELDDTO = _descriptor.Descriptor(
  name='SolarFieldDto',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problematic_tags', full_name='Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto.problematic_tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=479,
)

_TAGDATA.fields_by_name['tag_id'].message_type = Protobuf_dot_common__models__pb2._TAGSIDENTIFIERBASE
_TAGDATA.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAGDATA.fields_by_name['nullable_data'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_SOLARFIELDDTO.fields_by_name['data'].message_type = _TAGDATA
_SOLARFIELDDTO.fields_by_name['problematic_tags'].message_type = Protobuf_dot_common__models__pb2._PROBLEMATICTAG
DESCRIPTOR.message_types_by_name['TagData'] = _TAGDATA
DESCRIPTOR.message_types_by_name['SolarFieldDto'] = _SOLARFIELDDTO
DESCRIPTOR.enum_types_by_name['SfvCalculationMethod'] = _SFVCALCULATIONMETHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TagData = _reflection.GeneratedProtocolMessageType('TagData', (_message.Message,), {
  'DESCRIPTOR' : _TAGDATA,
  '__module__' : 'solar_field_common_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.TagData)
  })
_sym_db.RegisterMessage(TagData)

SolarFieldDto = _reflection.GeneratedProtocolMessageType('SolarFieldDto', (_message.Message,), {
  'DESCRIPTOR' : _SOLARFIELDDTO,
  '__module__' : 'solar_field_common_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDto)
  })
_sym_db.RegisterMessage(SolarFieldDto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
