# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual-trends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import common_models_pb2 as Protobuf_dot_common__models__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='virtual-trends.proto',
  package='Bsii.SolarFocus.Protobuf.Trends',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14virtual-trends.proto\x12\x1f\x42sii.SolarFocus.Protobuf.Trends\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cProtobuf/common-models.proto\x1a\x1egoogle/protobuf/wrappers.proto\"D\n\tDataPoint\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x02\"\x94\x01\n\x11TagTimeSeriesData\x12>\n\x08trend_id\x18\x01 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12?\n\x0btime_series\x18\x02 \x03(\x0b\x32*.Bsii.SolarFocus.Protobuf.Trends.DataPoint\"\xca\x02\n\x14TimeSeriesQueryInput\x12G\n\x11trends_identifier\x18\x01 \x03(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12\x32\n\x0estart_date_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nd_date_utc\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12N\n\x12\x63\x61lculation_method\x18\x04 \x01(\x0e\x32\x32.Bsii.SolarFocus.Protobuf.Trends.CalculationMethod\x12\x33\n\x10sample_frequency\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa0\x01\n\x15TimeSeriesQueryResult\x12\x42\n\x10problematic_tags\x18\x01 \x03(\x0b\x32(.Bsii.SolarFocus.Protobuf.ProblematicTag\x12\x43\n\x07results\x18\x02 \x03(\x0b\x32\x32.Bsii.SolarFocus.Protobuf.Trends.TagTimeSeriesData\"\xa0\x01\n\rTrendMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12.\n\tmin_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12.\n\tmax_value\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\x86\x03\n\x13VirtualTrendsModule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\nbase_image\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x05 \x01(\t\x12N\n\x12\x63\x61lculation_method\x18\x06 \x01(\x0e\x32\x32.Bsii.SolarFocus.Protobuf.Trends.CalculationMethod\x12\x33\n\x10sample_frequency\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x0cinput_trends\x18\x08 \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleInputTag\x12\x45\n\routput_trends\x18\t \x03(\x0b\x32..Bsii.SolarFocus.Protobuf.Trends.TrendMetadata*\xae\x01\n\x11\x43\x61lculationMethod\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12LINEAR_INTERPOLATE\x10\x01\x12\x1c\n\x18\x41VERAGE_OVER_SAMPLE_FREQ\x10\x02\x12\x18\n\x14MAX_OVER_SAMPLE_FREQ\x10\x03\x12\x18\n\x14MIN_OVRR_SAMPLE_FREQ\x10\x04\x12\x11\n\rLEFT_NEIGHBOR\x10\x05\x12\x12\n\x0eRIGHT_NEIGHBOR\x10\x06\x32\x94\x01\n\x18VirtualTrendsGrpcService\x12x\n\x07GetData\x12\x35.Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput\x1a\x36.Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResultB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,Protobuf_dot_common__models__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_CALCULATIONMETHOD = _descriptor.EnumDescriptor(
  name='CalculationMethod',
  full_name='Bsii.SolarFocus.Protobuf.Trends.CalculationMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR_INTERPOLATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVERAGE_OVER_SAMPLE_FREQ', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_OVER_SAMPLE_FREQ', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN_OVRR_SAMPLE_FREQ', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_NEIGHBOR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_NEIGHBOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1458,
  serialized_end=1632,
)
_sym_db.RegisterEnumDescriptor(_CALCULATIONMETHOD)

CalculationMethod = enum_type_wrapper.EnumTypeWrapper(_CALCULATIONMETHOD)
NONE = 0
LINEAR_INTERPOLATE = 1
AVERAGE_OVER_SAMPLE_FREQ = 2
MAX_OVER_SAMPLE_FREQ = 3
MIN_OVRR_SAMPLE_FREQ = 4
LEFT_NEIGHBOR = 5
RIGHT_NEIGHBOR = 6



_DATAPOINT = _descriptor.Descriptor(
  name='DataPoint',
  full_name='Bsii.SolarFocus.Protobuf.Trends.DataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='Bsii.SolarFocus.Protobuf.Trends.DataPoint.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.Trends.DataPoint.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=252,
)


_TAGTIMESERIESDATA = _descriptor.Descriptor(
  name='TagTimeSeriesData',
  full_name='Bsii.SolarFocus.Protobuf.Trends.TagTimeSeriesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trend_id', full_name='Bsii.SolarFocus.Protobuf.Trends.TagTimeSeriesData.trend_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_series', full_name='Bsii.SolarFocus.Protobuf.Trends.TagTimeSeriesData.time_series', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=403,
)


_TIMESERIESQUERYINPUT = _descriptor.Descriptor(
  name='TimeSeriesQueryInput',
  full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trends_identifier', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput.trends_identifier', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_utc', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput.start_date_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_utc', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput.end_date_utc', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput.calculation_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput.sample_frequency', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=736,
)


_TIMESERIESQUERYRESULT = _descriptor.Descriptor(
  name='TimeSeriesQueryResult',
  full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problematic_tags', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResult.problematic_tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResult.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=899,
)


_TRENDMETADATA = _descriptor.Descriptor(
  name='TrendMetadata',
  full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata.min_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata.max_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='Bsii.SolarFocus.Protobuf.Trends.TrendMetadata.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=1062,
)


_VIRTUALTRENDSMODULE = _descriptor.Descriptor(
  name='VirtualTrendsModule',
  full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_image', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.base_image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.environment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.calculation_method', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.sample_frequency', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_trends', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.input_trends', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_trends', full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule.output_trends', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1455,
)

_DATAPOINT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAGTIMESERIESDATA.fields_by_name['trend_id'].message_type = Protobuf_dot_common__models__pb2._TAGSIDENTIFIERBASE
_TAGTIMESERIESDATA.fields_by_name['time_series'].message_type = _DATAPOINT
_TIMESERIESQUERYINPUT.fields_by_name['trends_identifier'].message_type = Protobuf_dot_common__models__pb2._TAGSIDENTIFIERBASE
_TIMESERIESQUERYINPUT.fields_by_name['start_date_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESERIESQUERYINPUT.fields_by_name['end_date_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESERIESQUERYINPUT.fields_by_name['calculation_method'].enum_type = _CALCULATIONMETHOD
_TIMESERIESQUERYINPUT.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TIMESERIESQUERYRESULT.fields_by_name['problematic_tags'].message_type = Protobuf_dot_common__models__pb2._PROBLEMATICTAG
_TIMESERIESQUERYRESULT.fields_by_name['results'].message_type = _TAGTIMESERIESDATA
_TRENDMETADATA.fields_by_name['min_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRENDMETADATA.fields_by_name['max_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VIRTUALTRENDSMODULE.fields_by_name['calculation_method'].enum_type = _CALCULATIONMETHOD
_VIRTUALTRENDSMODULE.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VIRTUALTRENDSMODULE.fields_by_name['input_trends'].message_type = Protobuf_dot_common__models__pb2._VIRTUALMODULEINPUTTAG
_VIRTUALTRENDSMODULE.fields_by_name['output_trends'].message_type = _TRENDMETADATA
DESCRIPTOR.message_types_by_name['DataPoint'] = _DATAPOINT
DESCRIPTOR.message_types_by_name['TagTimeSeriesData'] = _TAGTIMESERIESDATA
DESCRIPTOR.message_types_by_name['TimeSeriesQueryInput'] = _TIMESERIESQUERYINPUT
DESCRIPTOR.message_types_by_name['TimeSeriesQueryResult'] = _TIMESERIESQUERYRESULT
DESCRIPTOR.message_types_by_name['TrendMetadata'] = _TRENDMETADATA
DESCRIPTOR.message_types_by_name['VirtualTrendsModule'] = _VIRTUALTRENDSMODULE
DESCRIPTOR.enum_types_by_name['CalculationMethod'] = _CALCULATIONMETHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataPoint = _reflection.GeneratedProtocolMessageType('DataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DATAPOINT,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.DataPoint)
  })
_sym_db.RegisterMessage(DataPoint)

TagTimeSeriesData = _reflection.GeneratedProtocolMessageType('TagTimeSeriesData', (_message.Message,), {
  'DESCRIPTOR' : _TAGTIMESERIESDATA,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.TagTimeSeriesData)
  })
_sym_db.RegisterMessage(TagTimeSeriesData)

TimeSeriesQueryInput = _reflection.GeneratedProtocolMessageType('TimeSeriesQueryInput', (_message.Message,), {
  'DESCRIPTOR' : _TIMESERIESQUERYINPUT,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryInput)
  })
_sym_db.RegisterMessage(TimeSeriesQueryInput)

TimeSeriesQueryResult = _reflection.GeneratedProtocolMessageType('TimeSeriesQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _TIMESERIESQUERYRESULT,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.TimeSeriesQueryResult)
  })
_sym_db.RegisterMessage(TimeSeriesQueryResult)

TrendMetadata = _reflection.GeneratedProtocolMessageType('TrendMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TRENDMETADATA,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.TrendMetadata)
  })
_sym_db.RegisterMessage(TrendMetadata)

VirtualTrendsModule = _reflection.GeneratedProtocolMessageType('VirtualTrendsModule', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTRENDSMODULE,
  '__module__' : 'virtual_trends_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsModule)
  })
_sym_db.RegisterMessage(VirtualTrendsModule)


DESCRIPTOR._options = None

_VIRTUALTRENDSGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualTrendsGrpcService',
  full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1635,
  serialized_end=1783,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetData',
    full_name='Bsii.SolarFocus.Protobuf.Trends.VirtualTrendsGrpcService.GetData',
    index=0,
    containing_service=None,
    input_type=_TIMESERIESQUERYINPUT,
    output_type=_TIMESERIESQUERYRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALTRENDSGRPCSERVICE)

DESCRIPTOR.services_by_name['VirtualTrendsGrpcService'] = _VIRTUALTRENDSGRPCSERVICE

# @@protoc_insertion_point(module_scope)
