# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual-sfv.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_models_pb2 as Protobuf_dot_common__models__pb2
from . import solar_field_common_pb2 as Protobuf_dot_solar__field__common__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='virtual-sfv.proto',
  package='Bsii.SolarFocus.Protobuf.SolarField',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11virtual-sfv.proto\x12#Bsii.SolarFocus.Protobuf.SolarField\x1a\x1cProtobuf/common-models.proto\x1a!Protobuf/solar-field-common.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x02\n\x08SfvQuery\x12\x32\n\x0equery_time_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x06margin\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12U\n\x12\x63\x61lculation_method\x18\x03 \x01(\x0e\x32\x39.Bsii.SolarFocus.Protobuf.SolarField.SfvCalculationMethod\x12G\n\x11tags_descriptions\x18\x04 \x03(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\">\n\x0bTagMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\x88\x03\n\x10VirtualSfvModule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\nbase_image\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x05 \x01(\t\x12U\n\x12\x63\x61lculation_method\x18\x06 \x01(\x0e\x32\x39.Bsii.SolarFocus.Protobuf.SolarField.SfvCalculationMethod\x12\x33\n\x10sample_frequency\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n\ninput_tags\x18\x08 \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleInputTag\x12\x45\n\x0boutput_tags\x18\t \x03(\x0b\x32\x30.Bsii.SolarFocus.Protobuf.SolarField.TagMetadata2\x85\x01\n\x15VirtualSfvGrpcService\x12l\n\x07GetData\x12-.Bsii.SolarFocus.Protobuf.SolarField.SfvQuery\x1a\x32.Bsii.SolarFocus.Protobuf.SolarField.SolarFieldDtoB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[Protobuf_dot_common__models__pb2.DESCRIPTOR,Protobuf_dot_solar__field__common__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SFVQUERY = _descriptor.Descriptor(
  name='SfvQuery',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_time_utc', full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvQuery.query_time_utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvQuery.margin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvQuery.calculation_method', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags_descriptions', full_name='Bsii.SolarFocus.Protobuf.SolarField.SfvQuery.tags_descriptions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=454,
)


_TAGMETADATA = _descriptor.Descriptor(
  name='TagMetadata',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.TagMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagMetadata.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='Bsii.SolarFocus.Protobuf.SolarField.TagMetadata.unit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=518,
)


_VIRTUALSFVMODULE = _descriptor.Descriptor(
  name='VirtualSfvModule',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_image', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.base_image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.environment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.calculation_method', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.sample_frequency', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_tags', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.input_tags', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_tags', full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule.output_tags', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=913,
)

_SFVQUERY.fields_by_name['query_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SFVQUERY.fields_by_name['margin'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SFVQUERY.fields_by_name['calculation_method'].enum_type = Protobuf_dot_solar__field__common__pb2._SFVCALCULATIONMETHOD
_SFVQUERY.fields_by_name['tags_descriptions'].message_type = Protobuf_dot_common__models__pb2._TAGSIDENTIFIERBASE
_VIRTUALSFVMODULE.fields_by_name['calculation_method'].enum_type = Protobuf_dot_solar__field__common__pb2._SFVCALCULATIONMETHOD
_VIRTUALSFVMODULE.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VIRTUALSFVMODULE.fields_by_name['input_tags'].message_type = Protobuf_dot_common__models__pb2._VIRTUALMODULEINPUTTAG
_VIRTUALSFVMODULE.fields_by_name['output_tags'].message_type = _TAGMETADATA
DESCRIPTOR.message_types_by_name['SfvQuery'] = _SFVQUERY
DESCRIPTOR.message_types_by_name['TagMetadata'] = _TAGMETADATA
DESCRIPTOR.message_types_by_name['VirtualSfvModule'] = _VIRTUALSFVMODULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SfvQuery = _reflection.GeneratedProtocolMessageType('SfvQuery', (_message.Message,), {
  'DESCRIPTOR' : _SFVQUERY,
  '__module__' : 'virtual_sfv_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.SfvQuery)
  })
_sym_db.RegisterMessage(SfvQuery)

TagMetadata = _reflection.GeneratedProtocolMessageType('TagMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TAGMETADATA,
  '__module__' : 'virtual_sfv_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.TagMetadata)
  })
_sym_db.RegisterMessage(TagMetadata)

VirtualSfvModule = _reflection.GeneratedProtocolMessageType('VirtualSfvModule', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALSFVMODULE,
  '__module__' : 'virtual_sfv_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvModule)
  })
_sym_db.RegisterMessage(VirtualSfvModule)


DESCRIPTOR._options = None

_VIRTUALSFVGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualSfvGrpcService',
  full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=916,
  serialized_end=1049,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetData',
    full_name='Bsii.SolarFocus.Protobuf.SolarField.VirtualSfvGrpcService.GetData',
    index=0,
    containing_service=None,
    input_type=_SFVQUERY,
    output_type=Protobuf_dot_solar__field__common__pb2._SOLARFIELDDTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALSFVGRPCSERVICE)

DESCRIPTOR.services_by_name['VirtualSfvGrpcService'] = _VIRTUALSFVGRPCSERVICE

# @@protoc_insertion_point(module_scope)
