# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import tags_metadata_pb2 as tags__metadata__pb2


class TagsMetadataGrpcServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUnfilteredAllMetaData = channel.unary_unary(
                '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetUnfilteredAllMetaData',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=tags__metadata__pb2.TagsMetadataDto.FromString,
                )
        self.GetUnfilteredSiteMetaData = channel.unary_unary(
                '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetUnfilteredSiteMetaData',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
                response_deserializer=tags__metadata__pb2.TagsMetadataDto.FromString,
                )
        self.GetSiteMetaData = channel.unary_unary(
                '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetSiteMetaData',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
                response_deserializer=tags__metadata__pb2.TagsMetadataDto.FromString,
                )
        self.UpdateTagMetaData = channel.unary_unary(
                '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/UpdateTagMetaData',
                request_serializer=tags__metadata__pb2.TagDto.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class TagsMetadataGrpcServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUnfilteredAllMetaData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUnfilteredSiteMetaData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSiteMetaData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTagMetaData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TagsMetadataGrpcServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUnfilteredAllMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnfilteredAllMetaData,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=tags__metadata__pb2.TagsMetadataDto.SerializeToString,
            ),
            'GetUnfilteredSiteMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnfilteredSiteMetaData,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.FromString,
                    response_serializer=tags__metadata__pb2.TagsMetadataDto.SerializeToString,
            ),
            'GetSiteMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSiteMetaData,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.StringValue.FromString,
                    response_serializer=tags__metadata__pb2.TagsMetadataDto.SerializeToString,
            ),
            'UpdateTagMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTagMetaData,
                    request_deserializer=tags__metadata__pb2.TagDto.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TagsMetadataGrpcService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUnfilteredAllMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetUnfilteredAllMetaData',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            tags__metadata__pb2.TagsMetadataDto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUnfilteredSiteMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetUnfilteredSiteMetaData',
            google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
            tags__metadata__pb2.TagsMetadataDto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSiteMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/GetSiteMetaData',
            google_dot_protobuf_dot_wrappers__pb2.StringValue.SerializeToString,
            tags__metadata__pb2.TagsMetadataDto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTagMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Bsii.SolarFocus.Protobuf.TagsMetadata.TagsMetadataGrpcService/UpdateTagMetaData',
            tags__metadata__pb2.TagDto.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
